Vercel's fx v0.0.15 is faster, smaller, and uses less memory
The Vercel developer account released fx v0.0.15: memory usage in long sessions reduced by 70%, binary size reduced by 7.66% (6.66MiB → 6.15MiB), image-heavy turn processing up to 3.3× faster, session resumes about 18% faster, plus automatic model catalog refresh and /fork for branching conversations. Guillermo Rauch shared it, saying fx is now faster, smaller, and more efficient.
Topics
View original postfx v0.0.15 Less memory. Faster resumes. Smaller binary. - 70% less memory in long sessions - 7.66% smaller binary (6.15mib ← 6.66mib) - Image-heavy turn processing up to 3.3× faster - Session resumes about 18% faster - Automatic model catalog refresh - Fork conversations with /fork - Better image handling & crash recovery in libfx - Multiple bug fixes & security improvements https://t.co/z3uxvmORfo
View original
fx v0.0.15 Less memory. Faster resumes. Smaller binary. - 70% less memory in long sessions - 7.66% smaller binary (6.15mib ← 6.66mib) - Image-heavy turn processing up to 3.3× faster - Session resumes about 18% faster - Automatic model catalog refresh - Fork conversations with /fork - Better image handling & crash recovery in libfx - Multiple bug fixes & security improvements https://t.co/z3uxvmORfo
Body
fx is now much faster, smaller and efficient Try https://t.co/3Z4NESzNKd on your iPhone Duo https://t.co/cA3yqS1od8